"use strict";
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _instances, _initialiseQR, _showNotification, _a, _instances_1, _getPeerId, _b;
Object.defineProperty(exports, "__esModule", { value: true });
exports.PeerToPeer = void 0;
const peerjs_1 = require("peerjs");
var QRCode = require('qrcode');
const jss_1 = require("jss");
const jss_preset_default_1 = require("jss-preset-default");
jss_1.default.setup((0, jss_preset_default_1.default)());
const styles = {
    'peer-connection-notification': {
        fontFamily: 'Verdana, Geneva, Tahoma, sans-serif',
        position: 'fixed',
        bottom: 5,
        transitionDuration: '0.5s',
        left: 'calc(50% - 175px)',
        textAlign: 'center',
        width: 350,
        height: 50,
        color: '#252525',
        background: 'white',
        border: '0.25px solid lightgray',
        borderRadius: 5,
    },
    'qr-container': {
        zIndex: 1000,
        fontFamily: 'Verdana, Geneva, Tahoma, sans-serif',
        '& .open-modal': {
            background: 'none',
            backgroundImage: " url('https://www.svgrepo.com/show/311122/qr-code.svg')",
            backgroundSize: 'contain',
            border: 0,
            position: 'fixed',
            right: 10,
            bottom: 10,
            height: 42,
            width: 42,
            transitionDuration: '0.1s',
            '&:hover': {
                cursor: 'pointer',
                opacity: 0.8,
            },
            '&:active': {
                transform: 'scale(0.9)',
                opacity: 0.5,
            },
        },
        '& .modal-back': {
            position: 'absolute',
            width: '100%',
            backgroundColor: 'rgba(0,0,0,0.4)',
            height: '100%',
            left: 0,
            top: 0,
            '& .modal': {
                width: 350,
                height: 320,
                backgroundColor: 'white',
                position: 'absolute',
                left: 'calc(50% - 175px)',
                top: 'calc(50% - 160px)',
                borderRadius: 7.5,
                '& .close-icon': {
                    width: 20,
                    height: 20,
                    backgroundImage: "url('https://www.svgrepo.com/show/305186/close.svg')",
                    cursor: 'pointer',
                    '&:hover': {
                        opacity: 0.6,
                    },
                    '&:active': {
                        opacity: 0.3,
                        transform: 'scale(0.9)',
                    },
                },
                '& .header': {
                    display: 'flex',
                    justifyContent: 'space-between',
                    alignItems: 'center',
                    paddingLeft: 17.5,
                    paddingRight: 17.5,
                    height: 50,
                    borderBottom: '0.25px solid lightgray',
                },
                '& .container': {
                    paddingLeft: 17.5,
                    fontSize: 12,
                    color: 'gray',
                },
                '& .qr-container': {
                    display: 'flex',
                    justifyContent: 'center',
                    alignItems: 'center',
                },
            },
        },
    },
};
const { classes } = jss_1.default.createStyleSheet(styles).attach();
class PeerToPeer {
}
exports.PeerToPeer = PeerToPeer;
PeerToPeer.Host = (_a = class {
        constructor(otherDeviceId, video = false) {
            _instances.add(this);
            this.otherDeviceId = otherDeviceId;
            this.peer = new peerjs_1.Peer();
            this.peer.on('open', () => {
                __classPrivateFieldGet(this, _instances, "m", _initialiseQR).call(this, this.peer.id);
            });
            if (video) {
            }
            else {
                this.peer.on('connection', (conn) => {
                    conn.on('data', (data) => {
                        if (data == 'connection-success-esp-tools') {
                            __classPrivateFieldGet(this, _instances, "m", _showNotification).call(this);
                        }
                        else {
                            console.log(data);
                        }
                    });
                });
            }
        }
        getVideo(func) {
            this.peer.on('call', function (call) {
                call.answer();
                call.on('stream', function (remoteStream) {
                    func(remoteStream);
                });
            });
        }
        onData(func) {
            this.peer.on('connection', (conn) => {
                conn.on('data', (data) => {
                    if (data == 'connection-success-esp-tools') {
                        __classPrivateFieldGet(this, _instances, "m", _showNotification).call(this);
                    }
                    else {
                        func(data);
                    }
                });
            });
        }
    },
    _instances = new WeakSet(),
    _initialiseQR = function _initialiseQR(id) {
        let path = `${this.otherDeviceId}?id=${id}`;
        QRCode.toCanvas(path, { errorCorrectionLevel: 'H' }, (err, canvas) => {
            if (err)
                throw err;
            var body = document.getElementsByTagName('body')[0];
            var qrcontainer = document.createElement('div');
            qrcontainer.className = classes['qr-container'];
            var open_modal_btn = document.createElement('button');
            open_modal_btn.className = 'open-modal';
            open_modal_btn.onclick = function () {
                let modal_back = document.createElement('div');
                modal_back.className = 'modal-back';
                let modal = document.createElement('div');
                modal.className = 'modal';
                let header = document.createElement('div');
                header.className = 'header';
                let title = document.createElement('p');
                title.innerText = 'Peer to peer';
                let closeIcon = document.createElement('div');
                closeIcon.className = 'close-icon';
                closeIcon.onclick = function () {
                    qrcontainer.removeChild(modal_back);
                };
                header.appendChild(title);
                header.appendChild(closeIcon);
                modal.appendChild(header);
                let subTextContainer = document.createElement('div');
                subTextContainer.className = 'container';
                subTextContainer.innerHTML = '<p>Connect to a mobile device</p>';
                modal.appendChild(subTextContainer);
                let qr_container = document.createElement('div');
                qr_container.className = 'qr-container';
                qr_container.appendChild(canvas);
                modal.appendChild(qr_container);
                modal_back.appendChild(modal);
                qrcontainer.appendChild(modal_back);
            };
            qrcontainer.appendChild(open_modal_btn);
            body.appendChild(qrcontainer);
        });
    },
    _showNotification = function _showNotification() {
        let root = document.getElementsByTagName('body')[0];
        let statusPopup = document.createElement('div');
        statusPopup.className = classes['peer-connection-notification'];
        statusPopup.innerHTML = '<p>Successful connection</p>';
        root.appendChild(statusPopup);
        setTimeout(function () {
            statusPopup.parentElement.removeChild(statusPopup);
        }, 2000);
    },
    _a);
PeerToPeer.Connector = (_b = class {
        constructor(video = false, direction = 'front') {
            _instances_1.add(this);
            this.peer = new peerjs_1.Peer();
            if (video) {
                var getUserMedia = navigator.getUserMedia ||
                    navigator.webkitGetUserMedia ||
                    navigator.mozGetUserMedia;
                getUserMedia({
                    video: {
                        facingMode: {
                            exact: direction == 'front' ? 'user' : 'environment',
                        },
                    },
                    audio: false,
                }, (stream) => {
                    var call = this.peer.call(__classPrivateFieldGet(this, _instances_1, "m", _getPeerId).call(this), stream);
                    let body = document.getElementsByTagName('body')[0];
                    let btn = document.createElement('button');
                    btn.id = 'close-btn-esp-tools';
                    btn.innerText = 'close connection';
                    btn.onclick = function () {
                        call.close();
                    };
                    body.appendChild(btn);
                });
            }
            else {
                setTimeout(() => {
                    this.conn = this.peer.connect(__classPrivateFieldGet(this, _instances_1, "m", _getPeerId).call(this), function (data) {
                        alert(data);
                    });
                    this.conn.on('open', () => {
                        this.conn.send('connection-success-esp-tools');
                    });
                }, 1000);
            }
        }
    },
    _instances_1 = new WeakSet(),
    _getPeerId = function _getPeerId() {
        const urlSearchParams = new URLSearchParams(window.location.search);
        const params = Object.fromEntries(urlSearchParams.entries());
        return params.id;
    },
    _b);
